@@ -10,22 +10,21 @@ def _required_version():
 
 
 def _installed_version():
-    return mtd.version("pkm_main")
+    try:
+        return mtd.version("pkm_main")
+    except mtd.PackageNotFoundError:
+        return ''
 
 
-def activate():
+def setup():
     data_dir = directories.data_dir()
     venv_dir = data_dir / 'venvs/pkm'
     required_version = _required_version()
 
-    print(f"will install version: {required_version}")
-
     if venv_dir.exists():
-        print("activating pkm environment...")
         venvs.activate(venv_dir)
 
         installed_version = _installed_version()
-        print(f"installed version: {installed_version}")
 
         if installed_version != required_version:
             _install(required_version)
@@ -38,4 +37,6 @@ def activate():
 
 
 def _install(version: str):
-    subprocess.check_call([sys.executable, "-m", "pip", "install", f'pkm-main=={version}'])
+    print("Needs to update my environment after upgrade/first-install... ")
+    subprocess.check_call([sys.executable, "-m", "pip", "install", f'pkm-main=={version}', "-qq"])
+    print("Update completed.")
